@@ -1,10 +1,5 @@
 {-# LANGUAGE Safe #-}
 
--- The following warning is enabled in this module so that the import of
--- Copilot.Core.External does not give rise to a warning. It can be removed
--- when that module is removed from the implementation.
-{-# OPTIONS_GHC -fno-warn-deprecations #-}
-
 -- |
 -- Description: Intermediate representation for Copilot specifications.
 -- Copyright:   (c) 2011 National Institute of Aerospace / Galois, Inc.
@@ -27,7 +22,6 @@
 -- ("Copilot.Core.PrettyPrint").
 module Copilot.Core
     ( module Copilot.Core.Expr
-    , module Copilot.Core.External
     , module Copilot.Core.Operators
     , module Copilot.Core.Spec
     , module Copilot.Core.Type
@@ -43,7 +37,6 @@ import Data.Word
 
 -- Internal imports
 import Copilot.Core.Expr
-import Copilot.Core.External -- See GHC flag enabled above
 import Copilot.Core.Operators
 import Copilot.Core.Spec
 import Copilot.Core.Type
