@@ -13,7 +13,7 @@ module Copilot.Core.PrettyPrint
 
 import Copilot.Core
 import Copilot.Core.Error (impossible)
-import Copilot.Core.Type.ShowInternal (showWithType, ShowType(..), showType)
+import Copilot.Core.Type.Show (showWithType, ShowType(..), showType)
 import Prelude hiding (id, (<>))
 import Text.PrettyPrint.HughesPJ
 import Data.List (intersperse)
